@@ -71,3 +71,24 @@ def get_holdout_result(project_id,model_id,client_token):
     headers = {"Authorization":client_token}
     response = requests.post(url,headers=headers,data=data)
     return response.json()
+
+
+def get_projectdetails(app_id,client_token):
+    url = f"{base_url}/training/project-details/{app_id}"
+    headers = {"Authorization":client_token}
+    response = requests.get(url,headers=headers)
+    return response.json()
+
+
+def get_jobdetails(app_id,client_token):
+    url = f"{base_url}/training/job-details?app_id={app_id}"
+    headers = {"Authorization":client_token}
+    response = requests.get(url,headers=headers)
+    return response.json()
+
+
+def get_deploymentdetails(project_id,client_token):
+    url = f"{base_url}/training/deployment-details/{project_id}"
+    headers = {"Authorization":client_token}
+    response = requests.get(url,headers=headers)
+    return response.json()
\ No newline at end of file
