@@ -1,8 +1,9 @@
 import requests
 import base64
-from ..config import base_url, api_token
-
+# from ..config import base_url, api_token
 
+base_url = "https://dev-aicloud-gateway.logicplum.com/api/v2"
+api_token = "i6DmueJGRHw1UYVcyKXmjSprOEWDRtCC7oqxJKuKzz7wXcAHHO9UPUQLlWt23AHx"
 def roc_plot(deployment_id,res_type,client_token):
     data = {
     "deployment_id": deployment_id,
@@ -11,6 +12,7 @@ def roc_plot(deployment_id,res_type,client_token):
     url = f"{base_url}/plot/roc"
     headers = {"Authorization":client_token}
     response = requests.post(url, data=data,headers=headers)
+    print(response.text)
     if data.get('res_type') == 'image':
         return response.content
     return response.json()
@@ -114,4 +116,10 @@ def confusion_matrix(deployment_id,res_type,client_token):
     response = requests.post(url, data=data,headers=headers)
     if data.get('res_type') == 'image':
         return response.content
-    return response.json()
\ No newline at end of file
+    return response.json()
+
+
+
+#test
+
+a = roc_plot("3991a687-9f1d-44bd-baea-b1bf91229c38","image","eyJuYW1lIjoiYWFiYiIsImVtYWlsIjoiYWFjY0B5b3BtYWlsLmNvbSJ9:1rGbLp:OOBiKlbYKo98hqXYSIc5U13Ls7CGE9bkbJHTtdRglPE")
\ No newline at end of file
