@@ -1,16 +1,10 @@
 import requests
-
-base_url = "https://dev-aicloud-gateway.logicplum.com/api/v2"
-api_token = "i6DmueJGRHw1UYVcyKXmjSprOEWDRtCC7oqxJKuKzz7wXcAHHO9UPUQLlWt23AHx"
+from ..config import base_url, api_token
 
 def get_prediction_status(deployment_or_project_id, client_token, mode):
     url = ""
     headers = {"Authorization": client_token}
-
-    if mode.lower() == "quick":
-        url = f"{base_url}/training/check-status/{deployment_or_project_id}"
-    else:
-        url = f"{base_url}/prediction/check-prediction-status/{deployment_or_project_id}"
+    url = f"{base_url}/prediction/check-prediction-status/{deployment_or_project_id}"
 
     try:
         response = requests.get(url, headers=headers)
